@@ -6,6 +6,7 @@ class ReadOnlyTabularInline(admin.TabularInline):
     Class for being extended by TabularInline-classes.
     Disables all create, delete or edit functionality in the tabular inline admin.
     """
+
     can_delete = False
 
     def has_add_permission(self, *args, **kwargs):
@@ -18,9 +19,11 @@ class ReadOnlyTabularInline(admin.TabularInline):
         return False
 
     def get_readonly_fields(self, request, obj=None):
-        result = list(set(
-            [field.name for field in self.opts.local_fields] +
-            [field.name for field in self.opts.local_many_to_many]
-        ))
+        result = list(
+            set(
+                [field.name for field in self.opts.local_fields]
+                + [field.name for field in self.opts.local_many_to_many]
+            )
+        )
         result.remove('id')
         return result
